BOOST_OS operating system macros

### `BOOST_OS` operating system macros

##### `BOOST_OS_AIX`

IBM AIX operating system. Version number available as major, minor, and patch.

Symbol | Version
--- | ---
`_AIX` | detection
`__TOS_AIX__` | detection
`_AIX43` | 4.3.0
`_AIX41` | 4.1.0
`_AIX32` | 3.2.0
`_AIX3` | 3.0.0

##### `BOOST_OS_AMIGAOS`

AmigaOS operating system.

Symbol | Version
--- | ---
`AMIGA` | detection
`__amigaos__` | detection

##### `BOOST_OS_ANDROID`

Android operating system.

Symbol | Version
--- | ---
`__ANDROID__` | detection

##### `BOOST_OS_BEOS`

BeOS operating system.

Symbol | Version
--- | ---
`__BEOS__` | detection

##### `BOOST_OS_BSD`

BSD operating system.

BSD has various branch operating systems possible and each detected individually. This detects the following variations and sets a specific version number macro to match:

- `BOOST_OS_BSD_DRAGONFLY` DragonFly BSD
- `BOOST_OS_BSD_FREE` FreeBSD
- `BOOST_OS_BSD_BSDI` BSDi BSD/OS
- `BOOST_OS_BSD_NET` NetBSD
- `BOOST_OS_BSD_OPEN` OpenBSD

| Note
The general `BOOST_OS_BSD` is set in all cases to indicate some form of BSD. If the above variants is detected the corresponding macro is also set.

Symbol | Version
--- | ---
`BSD` | detection
`_SYSTYPE_BSD` | detection
`BSD4_2` | 4.2.0
`BSD4_3` | 4.3.0
`BSD4_4` | 4.4.0
`BSD` | V.R.0

##### `BOOST_OS_CYGWIN`

Cygwin evironment.

Symbol | Version
--- | ---
`__CYGWIN__` | detection

##### `BOOST_OS_HAIKU`

Haiku operating system.

Symbol | Version
--- | ---
`__HAIKU__` | detection

##### `BOOST_OS_HPUX`

HP-UX operating system.

Symbol | Version
--- | ---
`hpux` | detection
`_hpux` | detection
`__hpux` | detection

##### `BOOST_OS_IOS`

iOS operating system.

Symbol | Version
--- | ---
`__APPLE__` | detection
`__MACH__` | detection
`__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__` | detection
`__ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__` | __ENVIRONMENT_IPHONE_OS_VERSION_MIN_REQUIRED__*1000

##### `BOOST_OS_IRIX`

IRIX operating system.

Symbol | Version
--- | ---
`sgi` | detection
`__sgi` | detection

##### `BOOST_OS_LINUX`

Linux operating system.

Symbol | Version
--- | ---
`linux` | detection
`__linux` | detection

##### `BOOST_OS_MACOS`

Mac OS operating system.

Symbol | Version
--- | ---
`macintosh` | detection
`Macintosh` | detection
`__APPLE__` | detection
`__MACH__` | detection
`__APPLE__`, `__MACH__` | 10.0.0
otherwise | 9.0.0

##### `BOOST_OS_OS400`

IBM OS/400 operating system.

Symbol | Version
--- | ---
`__OS400__` | detection

##### `BOOST_OS_QNX`

QNX operating system. Version number available as major, and minor if possible. And version 4 is specifically detected.

Symbol | Version
--- | ---
`__QNX__` | detection
`__QNXNTO__` | detection
`_NTO_VERSION` | V.R.0
`__QNX__` | 4.0.0

##### `BOOST_OS_SOLARIS`

Solaris operating system.

Symbol | Version
--- | ---
`sun` | detection
`__sun` | detection

##### `BOOST_OS_UNIX`

Unix Environment operating system.

Symbol | Version
--- | ---
`unix` | detection
`__unix` | detection
`_XOPEN_SOURCE` | detection
`_POSIX_SOURCE` | detection

##### `BOOST_OS_SVR4`

SVR4 Environment operating system.

Symbol | Version
--- | ---
`__sysv__` | detection
`__SVR4` | detection
`__svr4__` | detection
`_SYSTYPE_SVR4` | detection

##### `BOOST_OS_VMS`

VMS operating system.

Symbol | Version
--- | ---
`VMS` | detection
`__VMS` | detection
`__VMS_VER` | V.R.P

##### `BOOST_OS_WINDOWS`

Microsoft Windows operating system.

Symbol | Version
--- | ---
`_WIN32` | detection
`_WIN64` | detection
`__WIN32__` | detection
`__TOS_WIN__` | detection
`__WINDOWS__` | detection

##### `BOOST_OS_BSD_BSDI`

BSDi BSD/OS operating system.

Symbol | Version
--- | ---
`__bsdi__` | detection

##### `BOOST_OS_BSD_DRAGONFLY`

DragonFly BSD operating system.

Symbol | Version
--- | ---
`__DragonFly__` | detection

##### `BOOST_OS_BSD_FREE`

FreeBSD operating system.

Symbol | Version
--- | ---
`__FreeBSD__` | detection
`__FreeBSD_version` | V.R.P

##### `BOOST_OS_BSD_NET`

NetBSD operating system.

Symbol | Version
--- | ---
`__NETBSD__` | detection
`__NetBSD__` | detection
`__NETBSD_version` | V.R.P
`NetBSD0_8` | 0.8.0
`NetBSD0_9` | 0.9.0
`NetBSD1_0` | 1.0.0
`__NetBSD_Version` | V.R.P

##### `BOOST_OS_BSD_OPEN`

OpenBSD operating system.

Symbol | Version
--- | ---
`__OpenBSD__` | detection
`OpenBSD2_0` | 2.0.0
`OpenBSD2_1` | 2.1.0
`OpenBSD2_2` | 2.2.0
`OpenBSD2_3` | 2.3.0
`OpenBSD2_4` | 2.4.0
`OpenBSD2_5` | 2.5.0
`OpenBSD2_6` | 2.6.0
`OpenBSD2_7` | 2.7.0
`OpenBSD2_8` | 2.8.0
`OpenBSD2_9` | 2.9.0
`OpenBSD3_0` | 3.0.0
`OpenBSD3_1` | 3.1.0
`OpenBSD3_2` | 3.2.0
`OpenBSD3_3` | 3.3.0
`OpenBSD3_4` | 3.4.0
`OpenBSD3_5` | 3.5.0
`OpenBSD3_6` | 3.6.0
`OpenBSD3_7` | 3.7.0
`OpenBSD3_8` | 3.8.0
`OpenBSD3_9` | 3.9.0
`OpenBSD4_0` | 4.0.0
`OpenBSD4_1` | 4.1.0
`OpenBSD4_2` | 4.2.0
`OpenBSD4_3` | 4.3.0
`OpenBSD4_4` | 4.4.0
`OpenBSD4_5` | 4.5.0
`OpenBSD4_6` | 4.6.0
`OpenBSD4_7` | 4.7.0
`OpenBSD4_8` | 4.8.0
`OpenBSD4_9` | 4.9.0